==> auto_ui-0.0.2.tar.gz: lib/widgets/alert.dart <==
import 'package:flutter/material.dart';
import 'dart:math';

import './rpx.dart';
import './colors.dart';
import './enums.dart';
import './button.dart';

class AtAlert {
  static BuildContext _context;

  static Future<bool> show({
    @required BuildContext context,
    String title,
    String content = '',
    TextAlign contentTextAlign,
    String cancelText,
    String confirmText = '确定',
    VoidCallback onCancelPressed,
    VoidCallback onConfirmPressed,
    List<AtButton> buttons,
  }) {
    if (buttons == null || buttons.length == 0) {
      buttons = [];
      if (cancelText != null && cancelText != '') {
        buttons.add(AtButton(
          text: cancelText,
          theme: AtTheme.Default,
          onPressed: () {
            hide();
            if (onCancelPressed != null) onCancelPressed();
          },
        ));
      }
      buttons.add(AtButton(
        text: confirmText,
        onPressed: () {
          hide();
          if (onConfirmPressed != null) onConfirmPressed();
        },
      ));
    }

    // 保存当前上下文句柄
    _context = context;

    return _showAlert<bool>(
      context: context,
      builder: (BuildContext context) {
        return _Alert(
          title: title,
          content: content,
          contentTextAlign: contentTextAlign,
          buttons: buttons,
        );
      },
    );
  }

  static hide() {
    if (_context != null && Navigator.of(_context).canPop()) {
      Navigator.of(_context).pop();
      _context = null;
    }
  }
}

class _Alert extends Dialog with Rpx {
  final String title;
  final String content;
  final TextAlign contentTextAlign;
  final List<AtButton> buttons;

  _Alert({
    this.title,
    @required this.content,
    this.contentTextAlign = TextAlign.justify,
    @required this.buttons,
  });

  @override
  Widget build(BuildContext context) {
    List<Widget> _children = [];

    // 如果有title
    if (title != null && title != '') {
      _children.add(Text(
        title,
        style: TextStyle(
          color: AtColors.titleColor,
          fontWeight: FontWeight.bold,
          fontSize: frpx(36),
        ),
      ));
      _children.add(SizedBox(
        height: rpx(15),
      ));
    } else {
      _children.add(SizedBox(height: rpx(10)));
    }

    // content
    _children.add(
      Text(
        content,
        textAlign: contentTextAlign,
        style: TextStyle(
          color: title != null && title != '' ? AtColors.spanColor : AtColors.textColor,
          fontSize: frpx(28),
        ),
      ),
    );
    _children.add(SizedBox(height: rpx(60)));

    // 按钮
    List<Widget> _buttons = [];
    for (int i = 0; i < buttons.length; i++) {
      _buttons.add(Expanded(child: buttons[i]));
      if (i < buttons.length - 1) {
        _buttons.add(SizedBox(width: rpx(20)));
      }
    }
    _children.add(Container(
      height: rpx(88),
      child: Row(children: _buttons),
    ));

    return Material(
      type: MaterialType.transparency,
      child: Stack(
        children: <Widget>[
          Container(color: Colors.transparent),
          Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Container(
                  width: rpx(580),
                  padding: EdgeInsets.only(
                    top: rpx(50),
                    left: rpx(40),
                    right: rpx(40),
                    bottom: rpx(40),
                  ),
                  decoration: BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.circular(rpx(8)),
                    boxShadow: <BoxShadow>[
                      BoxShadow(
                        blurRadius: 20,
                        offset: Offset(0, 10),
                        color: Colors.black.withOpacity(0.05),
                      ),
                    ],
                  ),
                  child: Column(
                    children: _children,
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

Future<T> _showAlert<T>({
  @required BuildContext context,
  Widget child,
  WidgetBuilder builder,
}) {
  assert(child == null || builder == null);
  assert(debugCheckHasMaterialLocalizations(context));
  return showGeneralDialog(
    context: context,
    pageBuilder: (BuildContext buildContext, Animation<double> animation, Animation<double> secondaryAnimation) {
      final Widget pageChild = child ?? Builder(builder: builder);
      return SafeArea(
        child: Builder(builder: (BuildContext context) {
          return pageChild;
        }),
      );
    },
    barrierDismissible: true,
    barrierLabel: MaterialLocalizations.of(context).modalBarrierDismissLabel,
    barrierColor: AtColors.maskColor,
    transitionDuration: const Duration(milliseconds: 300),
    transitionBuilder: _buildMaterialDialogTransitions,
  );
}

Widget _buildMaterialDialogTransitions(
    BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) {
  return ScaleTransition(
    scale: Tween(begin: 0.95, end: 1.0).animate(animation),
    child: Opacity(
      opacity: max(animation.value * 2 - 1, 0),
      child: child,
    ),
  );
}

==> auto_ui-0.0.3.tar.gz: lib/widgets/alert.dart <==
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import './rpx.dart';
import './enums.dart';
import './colors.dart';
import './button.dart';

class AtAlert {
  static BuildContext _context;

  static Future show({
    @required BuildContext context,
    String title,
    String content = '',
    Widget child,
    TextAlign contentTextAlign = TextAlign.center,
    String cancelText,
    String confirmText = '确定',
    VoidCallback onCancelPressed,
    VoidCallback onConfirmPressed,
    List<AtButton> buttons,
    bool barrierDismissible = false,
  }) {
    assert(child != null || content != '');

    if (buttons == null || buttons.length == 0) {
      buttons = [];
      if (cancelText != null && cancelText != '') {
        buttons.add(AtButton(
          text: cancelText,
          theme: AtTheme.Default,
          onPressed: () {
            hide();
            if (onCancelPressed != null) onCancelPressed();
          },
        ));
      }
      buttons.add(AtButton(
        text: confirmText,
        onPressed: () {
          hide();
          if (onConfirmPressed != null) onConfirmPressed();
        },
      ));
    }

    // 保存当前上下文句柄
    _context = context;

    return _showAlert(
      context: context,
      builder: (BuildContext context) {
        return _Alert(
          title: title,
          content: content,
          child: child,
          contentTextAlign: contentTextAlign,
          buttons: buttons,
          barrierDismissible: barrierDismissible,
        );
      },
    );
  }

  static hide() {
    if (_context != null && Navigator.of(_context).canPop()) {
      Navigator.of(_context).pop();
      _context = null;
    }
  }
}

class _Alert extends Dialog with Rpx {
  final String title;
  final String content;
  final Widget child;
  final TextAlign contentTextAlign;
  final List<AtButton> buttons;
  final bool barrierDismissible;

  _Alert({
    this.title,
    this.content = '',
    this.child,
    this.contentTextAlign = TextAlign.justify,
    @required this.buttons,
    this.barrierDismissible = false,
  }) : assert(content != '' || child != null);

  @override
  Widget build(BuildContext context) {
    List<Widget> _children = [];

    // 如果有title
    if (title != null && title != '') {
      _children.add(Text(
        title,
        style: TextStyle(
          color: AtColors.titleColor,
          fontWeight: FontWeight.bold,
          fontSize: frpx(36),
        ),
      ));
      _children.add(SizedBox(
        height: rpx(15),
      ));
    } else {
      _children.add(SizedBox(height: rpx(10)));
    }

    // content
    if (content != '') {
      AlignmentGeometry _containerAlign;
      switch (this.contentTextAlign) {
        case TextAlign.center:
          _containerAlign = Alignment.topCenter;
          break;
        case TextAlign.end:
        case TextAlign.right:
          _containerAlign = Alignment.topRight;
          break;
        default:
          _containerAlign = Alignment.topLeft;
      }
      _children.add(
        Container(
          width: double.infinity,
          alignment: _containerAlign,
          child: Text(
            content,
            textAlign: contentTextAlign,
            style: TextStyle(
              color: title != null && title != '' ? AtColors.spanColor : AtColors.textColor,
              fontSize: frpx(28),
            ),
          ),
        ),
      );
    } else {
      _children.add(child);
    }
    _children.add(SizedBox(height: rpx(60)));

    // 按钮
    List<Widget> _buttons = [];
    for (int i = 0; i < buttons.length; i++) {
      _buttons.add(Expanded(child: buttons[i]));
      if (i < buttons.length - 1) {
        _buttons.add(SizedBox(width: rpx(20)));
      }
    }
    _children.add(Container(
      height: rpx(88),
      child: Row(children: _buttons),
    ));

    // 背景
    Widget _bg = Container(color: Colors.transparent);
    if (barrierDismissible) {
      _bg = GestureDetector(
        onTap: AtAlert.hide,
        child: _bg,
      );
    }

    return Material(
      type: MaterialType.transparency,
      child: Stack(
        children: <Widget>[
          _bg,
          Center(
            child: Container(
              width: rpx(580),
              padding: EdgeInsets.only(
                top: rpx(50),
                left: rpx(40),
                right: rpx(40),
                bottom: rpx(40),
              ),
              decoration: BoxDecoration(
                color: Colors.white,
                borderRadius: BorderRadius.circular(rpx(8)),
                boxShadow: <BoxShadow>[
                  BoxShadow(
                    blurRadius: 20,
                    offset: Offset(0, 10),
                    color: Colors.black.withOpacity(0.05),
                  ),
                ],
              ),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: _children,
              ),
            ),
          ),
        ],
      ),
    );
  }
}

Future<T> _showAlert<T>({
  @required BuildContext context,
  Widget child,
  WidgetBuilder builder,
}) {
  assert(child == null || builder == null);
  assert(debugCheckHasMaterialLocalizations(context));
  return showGeneralDialog(
    context: context,
    pageBuilder: (BuildContext buildContext, Animation<double> animation, Animation<double> secondaryAnimation) {
      final Widget pageChild = child ?? Builder(builder: builder);
      return SafeArea(
        child: Builder(builder: (BuildContext context) => pageChild),
      );
    },
    barrierDismissible: false,
    barrierLabel: MaterialLocalizations.of(context).modalBarrierDismissLabel,
    barrierColor: AtColors.maskColor,
    transitionDuration: const Duration(milliseconds: 200),
    transitionBuilder: _buildMaterialDialogTransitions,
  );
}

Widget _buildMaterialDialogTransitions(
    BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) {
  return ScaleTransition(
    scale: Tween(begin: 0.95, end: 1.0).animate(animation),
    child: Opacity(
      opacity: max(animation.value * 1.5 - 0.5, 0),
      child: child,
    ),
  );
}
